[Python-checkins] r60286 - python/trunk/Modules/mathmodule.c

christian.heimes python-checkins at python.org
Fri Jan 25 15:54:23 CET 2008


Author: christian.heimes
Date: Fri Jan 25 15:54:23 2008
New Revision: 60286

Modified:
   python/trunk/Modules/mathmodule.c
Log:
setup.py doesn't pick up changes to a header file

Modified: python/trunk/Modules/mathmodule.c
==============================================================================
--- python/trunk/Modules/mathmodule.c	(original)
+++ python/trunk/Modules/mathmodule.c	Fri Jan 25 15:54:23 2008
@@ -240,11 +240,11 @@
 					"math domain error");
 			return NULL;
 		}
-		/* Value is ~= x * 2**(e*SHIFT), so the log ~=
-		   log(x) + log(2) * e * SHIFT.
-		   CAUTION:  e*SHIFT may overflow using int arithmetic,
+		/* Value is ~= x * 2**(e*PyLong_SHIFT), so the log ~=
+		   log(x) + log(2) * e * PyLong_SHIFT.
+		   CAUTION:  e*PyLong_SHIFT may overflow using int arithmetic,
 		   so force use of double. */
-		x = func(x) + (e * (double)SHIFT) * func(2.0);
+		x = func(x) + (e * (double)PyLong_SHIFT) * func(2.0);
 		return PyFloat_FromDouble(x);
 	}
 


More information about the Python-checkins mailing list